packageVersion("phytools")
devtools::install_github("liamrevell/phytools")

library(phytools)
library(geiger)

##read tree file##
whale.tree <- read.tree(file="whaletree.tre")
whale.tree
plot(whale.tree)

##read data##
whale.data <- read.csv(file="whale_SC.csv",row.names=1,stringsAsFactors = TRUE)
head(whale.data)
whale.data

##extract variable##
whale_size <- setNames(whale.data$size, rownames(whale.data))

##model selection##
fitDiscrete(whale.tree, whale.data, model = "ER")
fitDiscrete(whale.tree, whale.data, model = "SYM")
fitDiscrete(whale.tree, whale.data, model = "ARD")

##stochastic mapping##
whale.maps.SYM <- make.simmap(whale.tree, whale_size, model="SYM", pi="fitzjohn",nsim=100)
summary(whale.maps.SYM)
#whale.maps.SYM <- make.simmap(whale.tree, whale_biogeo, model="ARD", pi="fitzjohn",nsim=100)
#whale.maps.SYM
#whale.maps.ER <- make.simmap(whale.tree, whale_biogeo, model="ER", pi="fitzjohn",nsim=100)
#whale.maps.ER


##compute LTTs SYM##
whale.ltts.SYM <- ltt(whale.maps.SYM)
cols <- setNames(c("#d03232", "#f9bd7e", "#e2abef", "#008bce"), levels(whale_size))
plot(whale.ltts.SYM, colors=cols, show.total=FALSE, bty="n", cex.axis=0.8, las=1, xlab="millions of years (from the root)", axes=FALSE)
axis(1,at=round(seq(0,max(nodeHeights(whale.tree)),length.out=4),1), cex.axis=0.8)
axis(2,las=1,cex.axis=0.8)
clip(0,max(nodeHeights(whale.tree)),0,Ntip(whale.tree))
grid()

##plotted with phylogeny##
obj<-summary(whale.maps.SYM)
par(mfrow=c(2,1))
plotTree(whale.tree,ftype="off",lwd=1,mar=c(0,4.1,0,1.1))
legend("bottomright",levels(whale_size),pch=22, pt.bg=cols,cex=0.8,pt.cex=1.2,bty="n")
par(fg="transparent")
nodelabels(pie=obj$ace,piecol=cols,cex=0.5)
tiplabels(pie=to.matrix(whale_size, levels(whale_size))[whale.tree$tip.label,],piecol=cols,cex=0.2)
par(fg="black")
par(mar=c(5.1,4.1,0,1.1))
plot(whale.ltts.SYM,colors=cols,show.total=FALSE,bty="n",cex.axis=0.8,las=1,xlab="millions of years (before present)",axes=FALSE,legend=FALSE)
axis(1,at=round(seq(0,max(nodeHeights(whale.tree)),length.out=4),1),label=round(seq(max(nodeHeights(whale.tree)),0,length.out=4),1),cex.axis=0.8)
axis(2,las=1,cex.axis=0.8)
clip(0,max(nodeHeights(whale.tree)),0,Ntip(whale.tree))
grid()

##plotted phylogeny with labels##
#obj<-summary(whale.maps.ARD)
#par(mfrow=c(2,1))
#plotTree(whale.tree,ftype="i",fsize=0.1,lwd=1,mar=c(0,4.1,0,1.1))
#legend("bottomright",levels(whale_biogeo),pch=22, pt.bg=cols,cex=0.8,pt.cex=1.2,bty="n")
#par(fg="transparent")
#nodelabels(pie=obj$ace,piecol=cols,cex=0.5)
#tiplabels(pie=to.matrix(whale_biogeo, levels(whale_biogeo))[whale.tree$tip.label,],piecol=cols,cex=0.2)
#par(fg="black")
#par(mar=c(5.1,4.1,0,1.1))
#plot(whale.ltts.ARD,colors=cols,show.total=FALSE,bty="n",cex.axis=0.8,las=1,xlab="millions of years (before present)",axes=FALSE,legend=FALSE)
#axis(1,at=round(seq(0,max(nodeHeights(whale.tree)),length.out=4),1),label=round(seq(max(nodeHeights(whale.tree)),0,length.out=4),1),cex.axis=0.8)
#axis(2,las=1,cex.axis=0.8)
#clip(0,max(nodeHeights(whale.tree)),0,Ntip(whale.tree))
#grid()
