library(RRphylo)
library(ape)
library (geiger)
library(picante)
library(nlme)
require(phytools)
library(paleotree)
library(phangorn)

#plot tree
whale.tree<-read.tree("RRwhaletree.tree")
plotTree(whale.tree)

nodelabels()

#import data
TBL<-read.csv("whale_TBL.csv",row.names=1, header = F, stringsAsFactors = F) 
TBL<-as.matrix(TBL)[,1]
TBL

#match data
TBL.plusTree <- treedata(whale.tree, TBL) #matches data frame species to phylogeny
TBL.plusTree

TBL.finalTree <- TBL.plusTree$phy
TBL.finalData <- as.data.frame(TBL.plusTree$data)

#run RRphylo
RRwhale <- RRphylo(tree=TBL.finalTree,y=TBL.finalData,cov=NULL,rootV=NULL,aces=NULL,x1=NULL,aces.x1=NULL)
RRwhale

#testing search.shift results
search.shift(RR=RRwhale, status.type = "clade",  f = 2, filename="C:/Users/rdun8/Documents/R/v1/Results") -> SSnode
SSnode 
cc <- 2/parallel::detectCores()
overfitwhale <- overfitRR(RR=RRwhale,y=TBL.finalData,swap.args=list(si=0.2,si2=0.2),shift.args=list(node=rownames(SSnode$single.clades), node=rownames(SSnode$all.clades),state=NULL),nsim=100,clus=cc)

overfitwhale$mean.sampling
overfitwhale$rootCI
overfitwhale$ace.regressions
overfitwhale$shift.results

#Ancestral state estimation
##before running this code, export the RRphylo output "aces" and evorates" into a CSV file
## read tree from file
whale.tree<-read.tree("RRwhaletree.tree")

## plot tree
plotTree(TBL.finalTree)
tiplabels()
nodelabels()
## read data
ace<-read.csv("aces.csv",row.names=1, header = F) ## or

## change this into a vector
ace<-as.matrix(ace)[,1]
ace

fit.all<-contMap(TBL.finalTree, TBL, plot=FALSE, method="user", anc.states=ace)
fit.all

obj.1 <- setMap(fit.all, colors = c("#008bce", "#b4ddf7", "#e2abef", "#f9bd7e", "#d03232"))

plot(obj.1)


###Map Evo rates###

## read data
rates<-read.csv("evo_rates.csv",row.names=1, header = F) ## or

## change this into a vector
rate<-as.matrix(rates)[,1]
rate

fit.all<-contMap(TBL.finalTree,rate,plot=FALSE,method="user",anc.states=rate)
fit.all

obj.1 <- setMap(fit.all, colors = c("#008bce", "#b4ddf7", "#e2abef", "#f9bd7e", "#d03232"))

plot(obj.1)

#####################
#generation time##

library(RRphylo)
library(ape)
library (geiger)
library(picante)
library(nlme)
require(phytools)
library(paleotree)
library(phangorn)

#plot tree
whale.tree<-read.tree("RRwhaletree.tree")
plotTree(whale.tree)

nodelabels()

#import data
TBL<-read.csv("whale_MGT.csv",row.names=1, header = F, stringsAsFactors = F) 
TBL<-as.matrix(TBL)[,1]
TBL

#match data
TBL.plusTree <- treedata(whale.tree, TBL) #matches data frame species to phylogeny
TBL.plusTree

TBL.finalTree <- TBL.plusTree$phy
TBL.finalData <- as.data.frame(TBL.plusTree$data)

#run RRphylo
RRwhale <- RRphylo(tree=TBL.finalTree,y=TBL.finalData,cov=NULL,rootV=NULL,aces=NULL,x1=NULL,aces.x1=NULL)
RRwhale

#testing search.shift results
search.shift(RR=RRwhale, status.type = "clade",  f = 2, filename="C:/Users/rdun8/Documents/R/v1/Results") -> SSnode
SSnode 
cc <- 2/parallel::detectCores()
overfitwhale <- overfitRR(RR=RRwhale,y=TBL.finalData,swap.args=list(si=0.2,si2=0.2),shift.args=list(node=rownames(SSnode$single.clades), node=rownames(SSnode$all.clades),state=NULL),nsim=100,clus=cc)

overfitwhale$mean.sampling
overfitwhale$rootCI
overfitwhale$ace.regressions
overfitwhale$shift.results

#Ancestral state estimation
##before running this code, export the RRphylo output "aces" and evorates" into a CSV file

## read data
ace<-read.csv("GM_aces.csv",row.names=1, header = F) ## or

## change this into a vector
ace<-as.matrix(ace)[,1]
ace

fit.all<-contMap(TBL.finalTree, TBL, plot=FALSE, method="user", anc.states=ace)
fit.all

obj.1 <- setMap(fit.all, colors = c("#008bce", "#b4ddf7", "#e2abef", "#f9bd7e", "#d03232"))

plot(obj.1)


###Map Evo rates###

## read data
rates<-read.csv("GM_evo_rates.csv",row.names=1, header = F) ## or

## change this into a vector
rate<-as.matrix(rates)[,1]
rate

fit.all<-contMap(TBL.finalTree,rate,plot=FALSE,method="user",anc.states=rate)
fit.all

obj.1 <- setMap(fit.all, colors = c("#008bce", "#b4ddf7", "#e2abef", "#f9bd7e", "#d03232"))

plot(obj.1)
